@@ -1,5 +1,5 @@
 /*
- * Blue Engine copyright 2021 © Elham Aryanpur
+ * Blue Engine by Elham Aryanpur
  *
  * The license is same as the one on the root.
 */
@@ -8,3 +8,4 @@ pub mod pipeline;
 pub mod shaders;
 pub mod vertex_buffer;
 pub mod uniform_buffer;
+pub mod texture;
